@@ -1,4 +1,4 @@
-#   Copyright 2020-2020 Exactpro (Exactpro Systems Limited)
+#   Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,20 +12,19 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-
 import json
-import logging
+import logging.config
 import os
-import threading
 from abc import ABC, abstractmethod
+from pathlib import Path
 from threading import Lock
 
 from th2_common.schema.cradle.cradle_configuration import CradleConfiguration
 from th2_common.schema.event.event_batch_router import EventBatchRouter
-from th2_common.schema.exception.common_factory_error import CommonFactoryError
 from th2_common.schema.grpc.configuration.grpc_router_configuration import GrpcRouterConfiguration
 from th2_common.schema.grpc.router.grpc_router import GrpcRouter
 from th2_common.schema.grpc.router.impl.default_grpc_router import DefaultGrpcRouter
+from th2_common.schema.log.trace import install_trace_logger
 from th2_common.schema.message.configuration.message_router_configuration import MessageRouterConfiguration
 from th2_common.schema.message.impl.rabbitmq.configuration.rabbitmq_configuration import RabbitMQConfiguration
 from th2_common.schema.message.impl.rabbitmq.connection.connection_manager import ConnectionManager
@@ -37,11 +36,15 @@ from th2_common.schema.message.message_router import MessageRouter
 from th2_common.schema.metrics.prometheus_configuration import PrometheusConfiguration
 from th2_common.schema.metrics.prometheus_server import PrometheusServer
 
-logger = logging.getLogger()
+
+logger = logging.getLogger(__name__)
 
 
 class AbstractCommonFactory(ABC):
 
+    DEFAULT_LOGGING_CONFIG_OUTER_PATH = Path('/var/th2/config/log4py.conf')
+    DEFAULT_LOGGING_CONFIG_INNER_PATH = Path(__file__).parent.parent.joinpath('log/config.conf')
+
     def __init__(self,
                  message_parsed_batch_router_class=RabbitParsedBatchRouter,
                  message_raw_batch_router_class=RabbitRawBatchRouter,
@@ -65,17 +68,28 @@ class AbstractCommonFactory(ABC):
         self._event_batch_router = None
         self._grpc_router = None
 
+        install_trace_logger()
+
+        if AbstractCommonFactory.DEFAULT_LOGGING_CONFIG_OUTER_PATH.exists():
+            logging.config.fileConfig(fname=AbstractCommonFactory.DEFAULT_LOGGING_CONFIG_OUTER_PATH,
+                                      disable_existing_loggers=False)
+            logger.info(f'Using logging config file from {AbstractCommonFactory.DEFAULT_LOGGING_CONFIG_OUTER_PATH}')
+        elif AbstractCommonFactory.DEFAULT_LOGGING_CONFIG_INNER_PATH.exists():
+            logging.config.fileConfig(fname=AbstractCommonFactory.DEFAULT_LOGGING_CONFIG_INNER_PATH,
+                                      disable_existing_loggers=False)
+            logger.info(f'Using logging config file from {AbstractCommonFactory.DEFAULT_LOGGING_CONFIG_INNER_PATH}')
+
         self._connection_manager = ConnectionManager(self.rabbit_mq_configuration)
 
-        self.prometheus_config = PrometheusConfiguration()
+        self.prometheus_config = self._create_prometheus_configuration()
         self.prometheus = PrometheusServer(self.prometheus_config.port, self.prometheus_config.host)
-        if self.prometheus_config.enabled is True:
+        if self.prometheus_config.enabled:
             self.prometheus.run()
 
     @property
     def message_parsed_batch_router(self) -> MessageRouter:
         """
-        Created MessageRouter which work with MessageBatch
+        Create MessageRouter which work with MessageBatch
         """
         if self._message_parsed_batch_router is None:
             self._message_parsed_batch_router = self.message_parsed_batch_router_class(self._connection_manager,
@@ -87,7 +101,7 @@ class AbstractCommonFactory(ABC):
     @property
     def message_raw_batch_router(self) -> MessageRouter:
         """
-        Created MessageRouter which work with RawMessageBatch
+        Create MessageRouter which work with RawMessageBatch
         """
         if self._message_raw_batch_router is None:
             self._message_raw_batch_router = self.message_raw_batch_router_class(self._connection_manager,
@@ -97,7 +111,7 @@ class AbstractCommonFactory(ABC):
     @property
     def message_group_batch_router(self) -> MessageRouter:
         """
-        Created MessageRouter which work with MessageGroupBatch
+        Create MessageRouter which work with MessageGroupBatch
         """
         if self._message_group_batch_router is None:
             self._message_group_batch_router = self.message_group_batch_router_class(self._connection_manager,
@@ -108,7 +122,7 @@ class AbstractCommonFactory(ABC):
     @property
     def event_batch_router(self) -> MessageRouter:
         """
-        Created MessageRouter which work with EventBatch
+        Create MessageRouter which work with EventBatch
         """
         if self._event_batch_router is None:
             self._event_batch_router = self.event_batch_router_class(self._connection_manager,
@@ -164,6 +178,8 @@ class AbstractCommonFactory(ABC):
         if self.prometheus.stopped is False:
             self.prometheus.stop()
 
+        logger.info('Common Factory is closed')
+
     @staticmethod
     def read_configuration(filepath):
         with open(filepath, 'r') as file:
@@ -176,8 +192,11 @@ class AbstractCommonFactory(ABC):
     def create_cradle_configuration(self) -> CradleConfiguration:
         return CradleConfiguration(**self.read_configuration(self._path_to_cradle_configuration()))
 
-    def create_prometheus_configuration(self) -> PrometheusConfiguration:
-        return PrometheusConfiguration(**self.read_configuration(self._path_to_prometheus_configuration()))
+    def _create_prometheus_configuration(self) -> PrometheusConfiguration:
+        if os.path.exists(self._path_to_prometheus_configuration()):
+            return PrometheusConfiguration(**self.read_configuration(self._path_to_prometheus_configuration()))
+        else:
+            return PrometheusConfiguration()
 
     def create_custom_configuration(self) -> dict:
         return self.read_configuration(self._path_to_custom_configuration())
