@@ -1,4 +1,4 @@
-#   Copyright 2020-2020 Exactpro (Exactpro Systems Limited)
+#   Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,9 +12,8 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-
-from th2_common.schema.message.configuration.configuration import Configuration
+from th2_common.schema.configuration.abstract_configuration import AbstractConfiguration
 
 
-class GrpcServiceConfiguration(Configuration):
+class GrpcServiceConfiguration(AbstractConfiguration):
     pass
