@@ -12,20 +12,19 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-
-from th2_common.schema.message.configuration.configuration import Configuration
+from th2_common.schema.configuration.abstract_configuration import AbstractConfiguration
 from th2_common.schema.message.configuration.mq_router_filter_configuration import MqRouterFilterConfiguration
 
 
-class QueueConfiguration(Configuration):
+class QueueConfiguration(AbstractConfiguration):
 
-    def __init__(self, name: str, queue: str, exchange: str, attributes: list, filters: list,
-                 prefetch_count: int = 1000, can_read=True, can_write=True) -> None:
+    def __init__(self, name: str, queue: str, exchange: str, attributes: list, filters: list, can_read=True,
+                 can_write=True, **kwargs) -> None:
         self.routing_key = name
         self.queue = queue
         self.exchange = exchange
-        self.prefetch_count = prefetch_count
         self.attributes = attributes
         self.filters = [MqRouterFilterConfiguration(**filter_schema) for filter_schema in filters]
         self.can_read = can_read
         self.can_write = can_write
+        self.check_unexpected_args(kwargs)
