@@ -27,9 +27,7 @@ class AbstractRabbitBatchMessageRouter(AbstractRabbitMessageRouter, ABC):
         result = dict()
         for message in self._get_messages(batch):
             for queue_alias in self._filter(queues, message):
-                if not result.__contains__(queue_alias):
-                    result[queue_alias] = self._create_batch()
-                    self._add_message(result[queue_alias], message)
+                self._add_message(result.setdefault(queue_alias, self._create_batch()), message)
         return result
 
     def _filter(self, queues: {str: QueueConfiguration}, message: Message) -> {str}:
@@ -37,7 +35,7 @@ class AbstractRabbitBatchMessageRouter(AbstractRabbitMessageRouter, ABC):
         for queue_alias in queues.keys():
             filters = queues[queue_alias].filters
 
-            if len(filters) == 0 or self._filter_strategy.verify(message, filters):
+            if len(filters) == 0 or self._filter_strategy.verify(message, router_filters=filters):
                 aliases.add(queue_alias)
         return aliases
 
