@@ -12,9 +12,13 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-class PrometheusConfiguration:
+from th2_common.schema.configuration.abstract_configuration import AbstractConfiguration
 
-    def __init__(self, host="0.0.0.0", port=9752, enabled=True) -> None:
+
+class PrometheusConfiguration(AbstractConfiguration):
+
+    def __init__(self, host="0.0.0.0", port=9752, enabled=True, **kwargs) -> None:
         self.host = host
         self.port = port
         self.enabled = enabled
+        self.check_unexpected_args(kwargs)
